==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/KubevirtPlatformStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class KubevirtPlatformStatusFluentImpl<A extends io.fabric8.openshift.api.model.KubevirtPlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.KubevirtPlatformStatusFluent<A>{
  public KubevirtPlatformStatusFluentImpl() {
  }
  public KubevirtPlatformStatusFluentImpl(io.fabric8.openshift.api.model.KubevirtPlatformStatus instance) {
    this.withApiServerInternalIP(instance.getApiServerInternalIP()); 
    this.withIngressIP(instance.getIngressIP()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiServerInternalIP;
  private java.lang.String ingressIP;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiServerInternalIP() {
    return this.apiServerInternalIP;
  }
  public A withApiServerInternalIP(java.lang.String apiServerInternalIP) {
    this.apiServerInternalIP=apiServerInternalIP; return (A) this;
  }
  public java.lang.Boolean hasApiServerInternalIP() {
    return this.apiServerInternalIP != null;
  }
  
  /**
   * Method is deprecated. use withApiServerInternalIP instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerInternalIP(java.lang.String arg0) {
    return (A)withApiServerInternalIP(new String(arg0));
  }
  public java.lang.String getIngressIP() {
    return this.ingressIP;
  }
  public A withIngressIP(java.lang.String ingressIP) {
    this.ingressIP=ingressIP; return (A) this;
  }
  public java.lang.Boolean hasIngressIP() {
    return this.ingressIP != null;
  }
  
  /**
   * Method is deprecated. use withIngressIP instead.
   */
  @java.lang.Deprecated
  public A withNewIngressIP(java.lang.String arg0) {
    return (A)withIngressIP(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KubevirtPlatformStatusFluentImpl that = (KubevirtPlatformStatusFluentImpl) o;
    if (apiServerInternalIP != null ? !apiServerInternalIP.equals(that.apiServerInternalIP) :that.apiServerInternalIP != null) return false;
    if (ingressIP != null ? !ingressIP.equals(that.ingressIP) :that.ingressIP != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiServerInternalIP,  ingressIP,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/KubevirtPlatformStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class KubevirtPlatformStatusFluentImpl<A extends io.fabric8.openshift.api.model.KubevirtPlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.KubevirtPlatformStatusFluent<A>{
  public KubevirtPlatformStatusFluentImpl() {
  }
  public KubevirtPlatformStatusFluentImpl(io.fabric8.openshift.api.model.KubevirtPlatformStatus instance) {
    this.withApiServerInternalIP(instance.getApiServerInternalIP()); 
    this.withIngressIP(instance.getIngressIP()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiServerInternalIP;
  private java.lang.String ingressIP;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiServerInternalIP() {
    return this.apiServerInternalIP;
  }
  public A withApiServerInternalIP(java.lang.String apiServerInternalIP) {
    this.apiServerInternalIP=apiServerInternalIP; return (A) this;
  }
  public java.lang.Boolean hasApiServerInternalIP() {
    return this.apiServerInternalIP != null;
  }
  
  /**
   * Method is deprecated. use withApiServerInternalIP instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerInternalIP(java.lang.String arg0) {
    return (A)withApiServerInternalIP(new String(arg0));
  }
  public java.lang.String getIngressIP() {
    return this.ingressIP;
  }
  public A withIngressIP(java.lang.String ingressIP) {
    this.ingressIP=ingressIP; return (A) this;
  }
  public java.lang.Boolean hasIngressIP() {
    return this.ingressIP != null;
  }
  
  /**
   * Method is deprecated. use withIngressIP instead.
   */
  @java.lang.Deprecated
  public A withNewIngressIP(java.lang.String arg0) {
    return (A)withIngressIP(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KubevirtPlatformStatusFluentImpl that = (KubevirtPlatformStatusFluentImpl) o;
    if (apiServerInternalIP != null ? !apiServerInternalIP.equals(that.apiServerInternalIP) :that.apiServerInternalIP != null) return false;
    if (ingressIP != null ? !ingressIP.equals(that.ingressIP) :that.ingressIP != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiServerInternalIP,  ingressIP,  additionalProperties,  super.hashCode());
  }
  
}
